import React from 'react';
import {
    Dialog,
    DialogTitle,
    DialogContent,
    IconButton,
    Typography,
    Grid,
} from '@mui/material';
import CloseIcon from '@mui/icons-material/Close';
import { SimpleTreeView, TreeItem } from '@mui/x-tree-view';

interface ExperimentParameters {
    id: number;
    run_number: number;
    beamline_parameters: {
        synchrotron: string;
        beamline: string;
        detector: {
            manufacturer: string;
            model: string;
            type: string;
            serialNumber: string;
            detectorDistance_mm: number;
            beamCenterX_px: number;
            beamCenterY_px: number;
            pixelSizeX_um: number;
            pixelSizeY_um: number;
        };
        // Include additional parameters as needed.
    };
    // Optionally, add fields for images and processing results.
    images?: Array<{
        id: number;
        filepath: string;
        comment?: string;
    }>;
    processingResults?: any;
}

interface RunDetailsProps {
    run: ExperimentParameters;
    onClose: () => void;
}

const RunDetails: React.FC<RunDetailsProps> = ({ run }) => {
    const { beamline_parameters } = run;
    const { synchrotron, beamline, detector } = beamline_parameters;

    return (
        <div style={{ padding: '16px', border: '1px solid #ccc', borderRadius: '4px' }}>
            <Typography variant="h6" gutterBottom>
                Run {run.run_number} Details
            </Typography>
            <Typography variant="subtitle1" gutterBottom>
                Beamline: {beamline} | Synchrotron: {synchrotron}
            </Typography>

            <SimpleTreeView
                defaultCollapseIcon="▾"
                defaultExpandIcon="▸"
                sx={{ fontSize: '0.875rem' }}
            >
                <TreeItem nodeId="detector-group" label={<strong>Detector Details</strong>}>
                    <TreeItem
                        nodeId="detector-manufacturer"
                        label={`Manufacturer: ${detector?.manufacturer || 'N/A'}`}
                    />
                    <TreeItem
                        nodeId="detector-model"
                        label={`Model: ${detector?.model || 'N/A'}`}
                    />
                    <TreeItem
                        nodeId="detector-type"
                        label={`Type: ${detector?.type || 'N/A'}`}
                    />
                    <TreeItem
                        nodeId="detector-serial"
                        label={`Serial Number: ${detector?.serialNumber || 'N/A'}`}
                    />
                    <TreeItem
                        nodeId="detector-distance"
                        label={`Distance (mm): ${detector?.detectorDistance_mm ?? 'N/A'}`}
                    />
                    <TreeItem
                        nodeId="beam-center"
                        label={
                            detector
                                ? `Beam Center: x: ${detector.beamCenterX_px}, y: ${detector.beamCenterY_px}`
                                : 'Beam Center: N/A'
                        }
                    />
                    <TreeItem
                        nodeId="pixel-size"
                        label={
                            detector
                                ? `Pixel Size (µm): x: ${detector.pixelSizeX_um}, y: ${detector.pixelSizeY_um}`
                                : 'Pixel Size: N/A'
                        }
                    />
                </TreeItem>
            </SimpleTreeView>

            <Typography variant="h6" sx={{ mt: 2 }}>
                Associated Images
            </Typography>
            {run.images && run.images.length > 0 ? (
                <Grid container spacing={2} sx={{ mt: 1 }}>
                    {run.images.map((img) => (
                        <Grid item xs={4} key={img.id}>
                            <img
                                src={img.filepath}
                                alt={img.comment || 'Sample Image'}
                                style={{ width: '100%', border: '1px solid #ccc' }}
                            />
                        </Grid>
                    ))}
                </Grid>
            ) : (
                <Typography>No images available.</Typography>
            )}

            <Typography variant="h6" sx={{ mt: 2 }}>
                Processing Results
            </Typography>
            {run.processingResults ? (
                <Typography variant="body2" sx={{ mt: 1 }}>
                    {JSON.stringify(run.processingResults, null, 2)}
                </Typography>
            ) : (
                <Typography variant="body2" sx={{ mt: 1 }}>
                    Processing details and results go here.
                </Typography>
            )}
        </div>
    );
};

export default RunDetails;